EzElevatedIconButton class

Inheritance

Constructors

EzElevatedIconButton({Key? key, bool enabled = true, void onPressed()?, void onLongPress()?, void onHover(bool)?, void onFocusChange(bool)?, bool underline = false, Color? decorationColor, ButtonStyle? style, FocusNode? focusNode, bool autofocus = false, Clip? clipBehavior, WidgetStatesController? statesController, required Widget icon, required String label, TextStyle? textStyle, TextAlign? textAlign, bool labelPadding = true})
ElevatedButton.icon wrapper that responds to isLeftyKey
const

Properties

autofocus bool
ElevatedButton.autofocus passthrough
final
clipBehavior Clip?
ElevatedButton.clipBehavior passthrough
final
decorationColor Color?
TextDecoration.underline's color Defaults to ColorScheme.primary
final
enabled bool
Easily disable the button Useful if the functionality is async
final
focusNode FocusNode?
ElevatedButton.focusNode passthrough
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
ElevatedButton.icon passthrough
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
ElevatedButton.icon's label will be Text with label, textStyle, and textAlign
final
labelPadding bool
Adds a '\t' sized EdgeInsets as prefix (righty) or suffix (lefty) to the label
final
onFocusChange → void Function(bool)?
Defaults to add an TextDecoration.underline to the label Can override and/or set underline to false
final
onHover → void Function(bool)?
Defaults to add an TextDecoration.underline to the label Can override and/or set underline to false
final
onLongPress → void Function()?
ElevatedButton.onLongPress passthrough
final
onPressed → void Function()?
ElevatedButton.onPressed passthrough
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statesController WidgetStatesController?
ElevatedButton.statesController passthrough
final
style ButtonStyle?
ElevatedButton.style passthrough
final
textAlign TextAlign?
Text.textAlign passthrough
final
textStyle TextStyle?
Defaults to TextTheme.bodyLarge
final
underline bool
Default false Adds an TextDecoration.underline to the label via onHover and onFocusChange
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EzElevatedIconButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited