EzElevatedLink class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- EzElevatedLink
Constructors
- EzElevatedLink({Key? key, String? tooltip, required String hint, required Uri? url, required String text})
-
Minimal EzElevatedButton wrapped in a
LinkIf you want an ElevatedButton with web Semantics and context menu Always has atooltip; if one is not provided, it will default tohintconst
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String
-
Semantics hint; what does it do?
Don't repeat text here, it is appended automatically
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
EzElevatedButton.text passthrough
final
- tooltip → String?
-
Tooltip.message passthrough
On hover/focus hint
Defaults to hint
final
- url → Uri?
-
Destination URL
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited