EzIconLink class

Inheritance

Constructors

EzIconLink({Key? key, required String label, TextStyle? style, required Widget icon, Color? textColor, Color? decorationColor, TextAlign? textAlign, EdgeInsets? padding, void onTap()?, Uri? url, required String hint, String? tooltip})
TextButton.icon wrapper that either opens an internal link via onTap Or an external link to url Always has a tool tooltip; if one is not provided, it will default to hint Highlights label with decorationColor and adds an TextDecoration.underline on hover/focus
const

Properties

decorationColor Color?
Defaults to ColorScheme.primary
final
hashCode int
The hash code for this object.
no setterinherited
hint String
Message for screen readers Don't repeat label here, it is appended automatically
final
icon Widget
TextButton.icon passthrough
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
The TextButton.icon label will be Text with label and all provided styling
final
onTap → void Function()?
Destination function Provide onTap or url, but not both
final
padding EdgeInsets?
Optional padding override for TextButton.style
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
Defaults to TextTheme.bodyLarge
final
textAlign TextAlign?
Text.textAlign passthrough
final
textColor Color?
Defaults to ColorScheme.onSurface
final
tooltip String?
Tooltip.message passthrough On hover/focus hint Defaults to hint
final
url Uri?
Destination URL Provide onTap or url, but not both
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EzIconLink>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited