EzLocaleSetting class

Inheritance

Constructors

EzLocaleSetting(void onComplete(), {Key? key, List<Locale>? locales, Set<Locale>? skip, Set<String> inDistress = const <String>{'US'}})
EzElevatedIconButton for updating the current Locale Opens a BottomSheet with a EzElevatedIconButton for each supported Locale
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inDistress Set<String>
Set of String language codes you'd like to protest
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locales List<Locale>?
Override EFUILang.supportedLocales default
final
onComplete → void Function()
EzConfig.rebuildLocale passthrough
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skip Set<Locale>?
Locales to skip Works for both default and custom locales
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EzLocaleSetting>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited