EzResetButton class

Inheritance

Constructors

EzResetButton(void onComplete(), {Key? key, bool all = true, required String appName, String? androidPackage, Set<String>? saveSkip, Widget? dialogContent, String dynamicTitle()?, Set<String>? resetSkip, Future<void> onConfirm()?, void onDeny()?})
EzElevatedIconButton for clearing user settings
const

Properties

all bool
Set to false for a 'Reset' ElevatedButton.icon label rather than 'Reset all' Also, when true there will be a local 'Reset all' switch When false, the current EzConfig.updateBoth value is used
final
androidPackage String?
ezRichUndoWarning passthrough
final
appName String
ezRichUndoWarning passthrough
final
dialogContent Widget?
Optionally override EzAlertDialog.content that shows on click Defaults to ezRichUndoWarning
final
dynamicTitle String Function()?
EzAlertDialog.title that shows on click
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onComplete → void Function()
EzConfig.rebuildUI passthrough
final
onConfirm Future<void> Function()?
Override what happens when the user choses to reset Defaults to EzConfig.reset DO NOT include an EzConfig.rebuildUI or Navigator.pop, these are included automatically
final
onDeny → void Function()?
Override what happens when the user choses not to reset DO NOT include a Navigator.pop, it is included automatically
final
resetSkip Set<String>?
EzConfig.reset skip passthrough Moot if onConfirm is provided
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveSkip Set<String>?
ezRichUndoWarning passthrough
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited