EzScreen class

Inheritance

Constructors

EzScreen(Widget child, {Key? key, AlignmentGeometry? alignment, EdgeInsetsGeometry? margin, bool useImageDecoration = true, Decoration? decoration, double height = double.infinity, double width = double.infinity})
Custom Container that creates a standard screen for EzConfig powered apps
const

Properties

alignment AlignmentGeometry?
Container.alignment passthrough
final
child Widget
Screen content
final
decoration Decoration?
Optional Decoration background for the screen If provided, must set useImageDecoration to false
final
hashCode int
The hash code for this object.
no setterinherited
height double
Screen height
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
Margin around the screen content
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useImageDecoration bool
Whether EzConfig.backgroundImagePath should be used to decorate the screen
final
width double
Screen width
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildDecoration() Decoration?
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited