EzDropdownMenu<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- EzDropdownMenu
Constructors
-
EzDropdownMenu({Key? key, FocusNode? focusNode, bool enabled = true, double? width, List<
String> ? widthEntries, double? iconSize, Widget? leadingIcon, Widget? trailingIcon, Widget? label, String? hintText, String? helperText, String? errorText, Widget? selectedTrailingIcon, bool enableFilter = false, bool enableSearch = true, TextInputType? keyboardType, TextStyle? textStyle, TextAlign textAlign = TextAlign.start, InputDecorationTheme? inputDecorationTheme, TextEditingController? controller, T? initialSelection, ValueChanged<T?> ? onSelected, bool? requestFocusOnTap, EdgeInsetsGeometry? expandedInsets, FilterCallback<T> ? filterCallback, SearchCallback<T> ? searchCallback, Offset? alignmentOffset, required List<DropdownMenuEntry< dropdownMenuEntries, List<T> >TextInputFormatter> ? inputFormatters}) -
DropdownMenu with custom styling
const
Properties
- alignmentOffset → Offset?
-
DropdownMenu.alignmentOffset passthrough
final
- controller → TextEditingController?
-
DropdownMenu.controller passthrough
final
-
dropdownMenuEntries
→ List<
DropdownMenuEntry< T> > -
DropdownMenu.dropdownMenuEntries passthrough
final
- enabled → bool
-
DropdownMenu.enabled passthrough
final
- enableFilter → bool
-
DropdownMenu.enableFilter passthrough
final
- enableSearch → bool
-
DropdownMenu.enableSearch passthrough
final
- errorText → String?
-
DropdownMenu.errorText passthrough
final
- expandedInsets → EdgeInsetsGeometry?
-
DropdownMenu.expandedInsets passthrough
final
-
filterCallback
→ FilterCallback<
T> ? -
DropdownMenu.filterCallback passthrough
final
- focusNode → FocusNode?
-
DropdownMenu.focusNode passthrough
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
DropdownMenu.helperText passthrough
final
- hintText → String?
-
DropdownMenu.hintText passthrough
final
- iconSize → double?
-
Optional IconButton.iconSize override
final
- initialSelection → T?
-
DropdownMenu.initialSelection passthrough
final
- inputDecorationTheme → InputDecorationTheme?
-
DropdownMenu.inputDecorationTheme passthrough
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
DropdownMenu.inputFormatters passthrough
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
DropdownMenu.keyboardType passthrough
final
- label → Widget?
-
DropdownMenu.label passthrough
final
- leadingIcon → Widget?
-
DropdownMenu.leadingIcon passthrough
final
-
DropdownMenu.menuHeight passthrough
final
-
DropdownMenu.menuStyle passthrough
final
-
onSelected
→ ValueChanged<
T?> ? -
DropdownMenu.onSelected passthrough
final
- requestFocusOnTap → bool?
-
DropdownMenu.requestFocusOnTap passthrough
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchCallback
→ SearchCallback<
T> ? -
DropdownMenu.searchCallback passthrough
final
- selectedTrailingIcon → Widget?
-
DropdownMenu.selectedTrailingIcon passthrough
final
- textAlign → TextAlign
-
DropdownMenu.textAlign passthrough
final
- textStyle → TextStyle?
-
DropdownMenu.textStyle passthrough
final
- trailingIcon → Widget?
-
DropdownMenu.trailingIcon passthrough
final
- width → double?
-
DropdownMenu.width passthrough
final
-
widthEntries
→ List<
String> ? -
Will set width to ezDropdownWidth of widthEntries
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited