EzTitleStyleProvider class
- Inheritance
-
- Object
- ChangeNotifier
- EzTextStyleProvider
- EzTitleStyleProvider
Constructors
- EzTitleStyleProvider()
- EzTextStyleProvider for ezTitleStyles values
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → TextStyle
-
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
bold(
bool bold) → void -
Toggle the TextStyle.fontWeight based on the passed
boldinherited -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
fuse(
String gFont) → void -
Run fuseWithGFont on the current TextStyle with the passed
gFontinherited -
italic(
bool italic) → void -
Toggle the TextStyle.fontStyle based on the passed
italicinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
redraw(
Color? color) → void -
Update the TextStyle.color to the passed
colorinherited -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
) → void - Reset via ezDefaultTitleStyle
-
resize(
double size) → void -
Update the TextStyle.fontSize to the passed
sizeinherited -
setHeight(
double height) → void -
Update the TextStyle.height to the passed
heightinherited -
setLetterSpacing(
double spacing) → void -
Update the TextStyle.letterSpacing to the passed
spacinginherited -
setWordSpacing(
double spacing) → void -
Update the TextStyle.wordSpacing to the passed
spacinginherited -
toString(
) → String -
A string representation of this object.
inherited
-
underline(
bool underline) → void -
Toggle the TextStyle.decoration based on the passed
underlineinherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited